# ==================================================================
#       文 件 名: __init__.py
#       概    要: Django数据库迁移优化
#       作    者: IT小强 
#       创建时间: 5/28/20 9:02 AM
#       修改时间: 
#       copyright (c) 2016 - 2020 mail@xqitw.cn
# ==================================================================

# 当前版本号
PACKAGE_VERSION = '3.0.2'

VERSION = tuple(PACKAGE_VERSION.split("."))

default_app_config = "django_kelove_db.apps.DjangoKeloveDbConfig"
